function [x,y,r0,alpha0] = geodesic(s,theta,npts)
% for given (s,\theta), returns a few points that describe the geodesic
% curve of parameters (s,\theta). npts designates the number of points
% used for the discrtization. 
% OUTPUT ARGS: - [x,y] : lists of points coordinates
%              - r0 : radius of the circle 
%              - alpha0 : half the angle of aperture of the arc circle

if abs(s) > 1,
    error(['s = ',num2str(s),', too large !']);
end

if s == 0, % construct a straight line
    
    x = -sin(theta)*(-1+1/npts:2/npts:1-1/npts);
    y = cos(theta)*(-1+1/npts:2/npts:1-1/npts);
    r0 = 0;
    
elseif abs(s)<=.9 % construct an arc circle
    
    r0 = .5*(1./s - s); % radius of the circle
    rho = .5*(1./s + s); % distance of the center from zero
    
    % angle range
    alpha0 = asin( 1/rho );
    
    alphamin = theta + pi - alpha0;
    alphamax = theta + pi + alpha0;
    
    dalpha = (alphamax-alphamin)/npts;
    alphas = alphamin+dalpha/2:dalpha:alphamax-dalpha/2;
    
    x = rho*cos(theta) + r0*cos(alphas);
    y = rho*sin(theta) + r0*sin(alphas);
else
    x=[];
    y=[];
    r0=0;
    alpha0=0;
end

end